Diffable

Trait Diffable 

pub trait Diffable {
    // Required method
    fn delta(&self, other: &Self) -> Self;
}
Elements that can be compared with another instance to produce a diff.

Required Methods

fn delta(&self, other: &Self) -> Self

Compare self with another struct of the same type and return a new instance containing the difference

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl Diffable for Option<OverallStats>

Source

fn delta(&self, other: &Self) -> Self

Implementors