pub trait Prettiable: Display {
// Provided methods
fn as_table(list: Vec<&Self>) -> Result<TableDisplay, EpochError>
where for<'a> Vec<&'a Self>: Table + WithTitle { ... }
fn show_as_log(&self) { ... }
fn as_log(&self) -> String { ... }
}Expand description
Elements that can be rendered into a pretty, human-readable form.
Provided Methods
Sourcefn as_table(list: Vec<&Self>) -> Result<TableDisplay, EpochError>
fn as_table(list: Vec<&Self>) -> Result<TableDisplay, EpochError>
Shows many items as a table.
Sourcefn show_as_log(&self)
fn show_as_log(&self)
Displays the struct as a log entry by printing the output of
as_log() to stdout.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.